# rcov Copyright (c) 2004-2006 Mauricio Fernandez <mfp@acm.org>
#
# See LEGAL and LICENSE for licensing information.

module Rcov

VERSION = "0.7.0"
RELEASE_DATE = "2006/08/04"
RCOVRT_ABI = [2,0,0]
UPSTREAM_URL = "http://eigenclass.org/hiki.rb?rcov"

end
# vi: set sw=2:
